@@ -1,11 +1,11 @@
-# Copyrights 2001-2014 by [Mark Overmeer].
+# Copyrights 2001-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.01.
 use strict;
 package Tools;
 use vars '$VERSION';
-$VERSION = '2.110';
+$VERSION = '2.118';
 
 
 use lib qw(lib ../lib);
@@ -53,12 +53,16 @@ BEGIN {
    $winfn   = 'mbox.win';
    $cpyfn   = 'mbox.cpy';
 
-   $unixsrc = File::Spec->catfile('folders', $unixfn);
-   $winsrc  = File::Spec->catfile('folders', $winfn);
-   $cpy     = File::Spec->catfile('folders', $cpyfn);
+   $unixsrc = File::Spec->catfile($folderdir, $unixfn);
+   $winsrc  = File::Spec->catfile($folderdir, $winfn);
+   $cpy     = File::Spec->catfile($folderdir, $cpyfn);
 
    ($src, $fn) = $crlf_platform ? ($winsrc, $winfn) : ($unixsrc, $unixfn);
 
+   # ensure to test the Perl Parser not the C-Parser (separate distribution)
+  require Mail::Box::Parser::Perl;
+  Mail::Box::Parser->defaultParserType( 'Mail::Box::Parser::Perl' );
+
    # IO::File::open() is wrapped, because starting with 1.11 (Perl 5.8.7)
    # it cannot open files with relative pathnames when tainting checks are
    # enabled.  I want to test relative folder names!!
